@@ -22,6 +22,11 @@
 """TMDA configuration variable defaults."""
 
 
+# NEVER make configuration changes to this file.  ALWAYS make them in
+# /etc/tmdarc or ~/.tmdarc instead.  Settings in ~/.tmdarc override
+# those in /etc/tmdarc.
+
+
 import binascii
 import os
 import stat
@@ -58,17 +63,19 @@ PARENTDIR = os.path.split(os.path.dirname(progpath))[0] # '../'
 # If the file /etc/tmdarc exists, read it before ~/.tmdarc.
 # Make site-wide configuration changes to this file.
 GLOBAL_TMDARC = '/etc/tmdarc'
-if os.path.exists(GLOBAL_TMDARC):
+if os.path.isfile(GLOBAL_TMDARC):
     try:
         execfile(GLOBAL_TMDARC)
     except:
         pass                            # just skip it if there is a problem
         
 # Look for the user-config-file in the environment first then default
-# to ~/.tmdarc.
+# to ~/.tmdarc or ~/.tmda/config
 TMDARC = os.environ.get('TMDARC')
 if not TMDARC:
-    TMDARC = os.path.expanduser("~/.tmdarc")
+    TMDARC = os.path.expanduser('~/.tmdarc')
+    if not os.path.isfile(TMDARC):
+        TMDARC = os.path.expanduser('~/.tmda/config')
 
 # Read-in the user's configuration file.
 if os.path.exists(TMDARC):
@@ -169,6 +176,10 @@ if not vars().has_key('VIRTUALDOMAINS'):
 
 # BOUNCE_ENV_SENDER
 # The envelope sender of the bounce message.
+#
+# Example:
+# BOUNCE_ENV_SENDER = "devnull@domain.dom"
+#
 # Default is an empty envelope sender <>.
 if not vars().has_key('BOUNCE_ENV_SENDER'):
     # Exim and Sendmail don't like -f ''
@@ -202,6 +213,10 @@ if not vars().has_key('BOUNCE_TEXT_NONEXISTENT_PENDING'):
 # Filename to which a recipient's e-mail address should be
 # automatically appended if the outgoing <action> is in the form
 # 'bare=append'.
+#
+# Example:
+# BARE_APPEND = "/full/path/to/whitelist"
+#
 # No default
 if not vars().has_key('BARE_APPEND'):
     BARE_APPEND = None
@@ -213,6 +228,9 @@ if not vars().has_key('BARE_APPEND'):
 # confirmation address be based on a fixed address regardless of the
 # recipient address.
 #
+# Example:
+# CONFIRM_ADDRESS = "webmaster@domain.dom"
+#
 # No default
 if not vars().has_key('CONFIRM_ADDRESS'):
     CONFIRM_ADDRESS = None
@@ -221,6 +239,10 @@ if not vars().has_key('CONFIRM_ADDRESS'):
 # Filename to which a sender's e-mail address should be automatically
 # appended once they confirm a message.  This can be used to implement
 # "auto-whitelisting" functionality.
+#
+# Example:
+# CONFIRM_APPEND = "/full/path/to/whitelist"
+#
 # No default
 if not vars().has_key('CONFIRM_APPEND'):
     CONFIRM_APPEND = None
@@ -228,6 +250,10 @@ if not vars().has_key('CONFIRM_APPEND'):
 # CONFIRM_CC
 # An optional e-mail address which will be sent a copy of any message
 # that triggers a confirmation request.
+#
+# Example:
+# CONFIRM_CC = "jdoe-confirms@domain.dom"
+#
 # No default.
 if not vars().has_key('CONFIRM_CC'):
     CONFIRM_CC = None
@@ -269,6 +295,11 @@ if not vars().has_key('CONFIRM_ACCEPT_TEXT_ALREADY_RELEASED'):
 # CONFIRM_ACCEPT_CC
 # An optional e-mail address which will be sent a copy of the
 # confirmation acceptance messages people send you.
+#
+# Example:
+# CONFIRM_ACCEPT_CC = "jdoe-confirm-replies@domain.dom"
+#
+# No default.
 if not vars().has_key('CONFIRM_ACCEPT_CC'):
     CONFIRM_ACCEPT_CC = None
 
@@ -284,6 +315,10 @@ if not vars().has_key('CONFIRM_MAX_MESSAGE_SIZE'):
 # Full path to a directory containing custom TMDA templates.  Any
 # templates found in this directory will be used, otherwise the
 # default templates will be used.
+#
+# Example:
+# TEMPLATE_DIR = "/full/path/to/templates/"
+#
 # No default.
 if not vars().has_key('TEMPLATE_DIR'):
     TEMPLATE_DIR = None
@@ -315,27 +350,31 @@ else:
     
 # FILTER_INCOMING
 # Filter file which controls how incoming messages are tagged.
-# Default is ~/.tmda/filters/incoming
 # Look for the filter-file in the environment first.
+# Default is ~/.tmda/filters/incoming
 env_FILTER_INCOMING = os.environ.get('TMDA_FILTER_INCOMING')
 if env_FILTER_INCOMING:
     FILTER_INCOMING = env_FILTER_INCOMING
 elif not vars().has_key('FILTER_INCOMING'):
-    FILTER_INCOMING = DATADIR + "filters/" + "incoming"
+    FILTER_INCOMING = os.path.join(DATADIR, 'filters', 'incoming')
 
 # FILTER_OUTGOING
 # Filter file which controls how outgoing messages are tagged.
-# Default is ~/.tmda/filters/outgoing
 # Look for the filter-file in the environment first.
+# Default is ~/.tmda/filters/outgoing
 env_FILTER_OUTGOING = os.environ.get('TMDA_FILTER_OUTGOING')
 if env_FILTER_OUTGOING:
     FILTER_OUTGOING = env_FILTER_OUTGOING
 elif not vars().has_key('FILTER_OUTGOING'):
-    FILTER_OUTGOING = DATADIR + "filters/" + "outgoing"
+    FILTER_OUTGOING = os.path.join(DATADIR, 'filters', 'outgoing')
     
 # FILTER_BOUNCE_CC
 # An optional e-mail address which will be sent a copy of any message
 # that bounces because of a match in FILTER_INCOMING.
+#
+# Example:
+# FILTER_BOUNCE_CC = "jdoe-bounces@domain.dom"
+#
 # No default.
 if not vars().has_key('FILTER_BOUNCE_CC'):
     FILTER_BOUNCE_CC = None
@@ -343,6 +382,10 @@ if not vars().has_key('FILTER_BOUNCE_CC'):
 # FILTER_DROP_CC
 # An optional e-mail address which will be sent a copy of any message
 # that is dropped because of a match in FILTER_INCOMING.
+#
+# Example:
+# FILTER_DROP_CC = "jdoe-drops@domain.dom"
+#
 # No default.
 if not vars().has_key('FILTER_DROP_CC'):
     FILTER_DROP_CC = None
@@ -444,6 +487,10 @@ if not vars().has_key('FINGERPRINT'):
     
 # FULLNAME
 # Your full name.
+#
+# Example:
+# FULLNAME = "John Doe"
+#
 # Default comes from your environment or the password file.
 if not vars().has_key('FULLNAME'):
     FULLNAME = Util.getfullname()
@@ -457,23 +504,43 @@ if not vars().has_key('HMAC_BYTES'):
     HMAC_BYTES = 3
 
 # HOSTNAME
-# The right-hand side of your email address (after `@').
+# The right-hand side of your email address (after `@').  Used only in
+# cases where TMDA can't determine this itself.
+#
+# Example:
+# HOSTNAME = "domain.dom"
+#
 # Defaults to the fully qualified domain name of the localhost.
 if not vars().has_key('HOSTNAME'):
     HOSTNAME = Util.gethostname()
     
 # LOGFILE_DEBUG
 # Filename which uncaught exceptions should be written to.
+#
+# Example:
+# LOGFILE_DEBUG = "/path/to/tmda_debug.log"
+#
 # No default.
 if not vars().has_key('LOGFILE_DEBUG'):
     LOGFILE_DEBUG = None
     
 # LOGFILE_INCOMING
 # Filename which delivery summaries should be written to.
+#
+# Example:
+# LOGFILE_INCOMING = "/path/to/tmda_incoming.log"
+#
 # No default.
 if not vars().has_key('LOGFILE_INCOMING'):
     LOGFILE_INCOMING = None
 
+# LOCALDATE
+# Set this variable to 0 if you want TMDA to generate ``Date:''
+# headers in UTC instead of the local time zone.
+# Default is 1 (use local time zone)
+if not vars().has_key('LOCALDATE'):
+    LOCALDATE = 1
+
 # MESSAGE_FROM_STYLE
 # Specifies how `From' headers should look when tagging outgoing
 # messages with tmda-sendmail.  There are two valid values:
@@ -497,9 +564,15 @@ if not vars().has_key('DELIVERED_CACHE'):
     DELIVERED_CACHE = os.path.join(DATADIR, 'pending', '.delivered_cache')
 
 # DELIVERED_CACHE_LEN
+#
 # An integer which specifies the maximum number of entries held by
 # DELIVERED_CACHE.
 #
+# Make sure this value is larger than the number of messages normally
+# stored in your pending queue.  The default value may not suffice if
+# you run a very high traffic TMDA, and/or have a long pending queue
+# purge interval.
+#
 # Default is 5000
 if not vars().has_key('DELIVERED_CACHE_LEN'):
     DELIVERED_CACHE_LEN = 5000
@@ -522,6 +595,28 @@ if not vars().has_key('PENDING_CACHE'):
 if not vars().has_key('PENDING_CACHE_LEN'):
     PENDING_CACHE_LEN = 5000
 
+# PENDING_DELETE_APPEND
+# Filename to which a sender's e-mail address should be automatically
+# appended when a message is "deleted" by tmda-pending.
+#
+# Example:
+# PENDING_DELETE_APPEND = "/full/path/to/blacklist"
+#
+# No default
+if not vars().has_key('PENDING_DELETE_APPEND'):
+    PENDING_DELETE_APPEND = None
+
+# PENDING_RELEASE_APPEND
+# Filename to which a sender's e-mail address should be automatically
+# appended when a message is "released" by tmda-pending.
+#
+# Example:
+# PENDING_RELEASE_APPEND = "/full/path/to/whitelist"
+#
+# No default
+if not vars().has_key('PENDING_RELEASE_APPEND'):
+    PENDING_RELEASE_APPEND = None
+
 # PURGED_HEADERS
 # A list containing one or more message headers that should be removed
 # from outgoing client-side messages (i.e, messages sent with
@@ -567,6 +662,22 @@ if not vars().has_key('PURGED_HEADERS'):
 if not vars().has_key('RECIPIENT_HEADER'):
     RECIPIENT_HEADER = None
 
+# TERSE_SUMMARY_HEADERS
+# A list containing one or more message headers that should be
+# displayed by tmda-pending's `--terse option'.  Listed headers are
+# case-insensitive.  'from_name' and 'from_address' can be used to
+# specify the Fullname and e-mail address from the message's "From:"
+# header.
+#
+# Examples:
+#
+# TERSE_SUMMARY_HEADERS = ["return-path"]
+# TERSE_SUMMARY_HEADERS = ["from_name", "from_address", "subject"]
+#
+# Default is the Fullname followed by Subject.
+if not vars().has_key('TERSE_SUMMARY_HEADERS'):
+    TERSE_SUMMARY_HEADERS = ['from_name', 'subject']
+
 # TIMEOUT
 # The timeout interval for 'dated' addresses.  The available units are
 # (Y=years, M=months, w=weeks, d=days, h=hours, m=minutes, s=seconds).
@@ -576,6 +687,10 @@ if not vars().has_key('TIMEOUT'):
 
 # USERNAME
 # The left-hand side of your e-mail address (before `@').
+#
+# Example:
+# USERNAME = "jdoe"
+#
 # Defaults to your UNIX username.
 if not vars().has_key('USERNAME'):
     USERNAME = Util.getusername()
