@@ -19,33 +19,25 @@
 # along with TMDA; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-""" Various versioning information."""
+"""Various versioning information."""
 
 
-import os
 import sys
 
 
 # TMDA version
-TMDA = "0.52"
+TMDA = "0.54"
 
 # Python version
-# e.g, 2.2 
 PYTHON = sys.version.split()[0]
 
+# Platform identifier
 try:
-    # System information (sysname, nodename, release, version, machine)
-    # e.g, ('OSF1', 'spe147', 'V5.1', '1885', 'alpha')
-    UNAME = os.uname()
-    SYSNAME = UNAME[0].replace(' ', '_').replace('/', '_') # OSF1
-    MACHINE = UNAME[4].replace(' ', '_').replace('/', '_') # alpha
-    PLATFORM = SYSNAME + '/' + MACHINE  # OSF1/alpha
-except AttributeError:
-    # Fall back to using just sys.platform for PLATFORM if uname isn't
-    # available on this host.
-    UNAME = SYSNAME = MACHINE = None
-    PLATFORM = sys.platform             # osf1V5
-    
+    from distutils.util import get_platform
+    PLATFORM = get_platform()
+except ImportError:
+    PLATFORM = sys.platform
+
 # Summary of all the version identifiers
-# e.g, TMDA/0.49 (Python 2.2 on OSF1/alpha)
+# e.g, TMDA/0.52 (Python 2.2.1 on osf1-V5.1-alpha)
 ALL = "TMDA/%s (Python %s on %s)" % (TMDA, PYTHON, PLATFORM)
